from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

## exchanges #####################################################################################################################################

@daily_cache
def all_public_companies():
    return get_json("/market/all-public-companies").get("stocks")

@daily_cache
def nasdaq_exchange_composition():
    return get_json("/market/exchange/nasdaq").get("stocks")

@daily_cache
def nyse_composition():
    return get_json("/market/exchange/nyse").get("stocks")

@daily_cache
def shanghai_exchange_composition():
    return get_json("/market/exchange/shanghai-stock-exchange").get("stocks")

@daily_cache
def hong_kong_exchange_composition():
    return get_json("/market/exchange/hong-kong-stock-exchange").get("stocks")

@daily_cache
def london_exchange_composition():
    return get_json("/market/exchange/london-stock-exchange").get("stocks")


from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

@daily_cache
def business_description_similarity(ticker_symbol1,ticker_symbol2):
    params = {"ticker_symbol1": ticker_symbol1, "ticker_symbol2": ticker_symbol2}
    return get_json("/stock-similarity/business-description-similarity", params).get("similarity")

@daily_cache
def industry_similarity(ticker_symbol1,ticker_symbol2):
    params = {"ticker_symbol1": ticker_symbol1, "ticker_symbol2": ticker_symbol2}
    return get_json("/stock-similarity/industry-similarity", params).get("similarity")

@daily_cache
def stock_price_correlation(ticker_symbol1,ticker_symbol2):
    params = {"ticker_symbol1": ticker_symbol1, "ticker_symbol2": ticker_symbol2}
    return get_json("/stock-similarity/stock-price-correlation", params).get("similarity")




from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

## Basics #########################################################################################################################################

@daily_cache
def annual_balance_sheet(ticker_symbol):
    return get_json("/stock/financials/balance-sheet/annual-historical", {"ticker_symbol": ticker_symbol})

@daily_cache
def quarterly_balance_sheet(ticker_symbol):
    return get_json("/stock/financials/balance-sheet/quarterly-historical", {"ticker_symbol": ticker_symbol})

@daily_cache
def latest_annual_balance_sheet(ticker_symbol):
    return get_json("/stock/financials/balance-sheet/annual-latest", {"ticker_symbol": ticker_symbol})

@daily_cache
def latest_quarterly_balance_sheet(ticker_symbol):
    return get_json("/stock/financials/balance-sheet/quarterly-latest", {"ticker_symbol": ticker_symbol})

@daily_cache
def annual_income_statement(ticker_symbol):
    return get_json("/stock/financials/income-statement/annual-historical", {"ticker_symbol": ticker_symbol})

@daily_cache
def quarterly_income_statement(ticker_symbol):
    return get_json("/stock/financials/income-statement/quarterly-historical", {"ticker_symbol": ticker_symbol})

@daily_cache
def latest_annual_income_statement(ticker_symbol):
    return get_json("/stock/financials/income-statement/annual-latest", {"ticker_symbol": ticker_symbol})

@daily_cache
def latest_quarterly_income_statement(ticker_symbol):
    return get_json("/stock/financials/income-statement/quarterly-latest", {"ticker_symbol": ticker_symbol})


## Income statement line items ####################################################################################################################

def revenue(self, ticker_symbol):
    return latest_annual_income_statement(ticker_symbol).get("Total Revenue", 0.0)

def gross_profit(self, ticker_symbol):
    return latest_annual_income_statement(ticker_symbol).get("Gross Profit", 0.0)





from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

## screeners ###################################################################################################################################

@daily_cache
def conservative_foreign_funds():
    return get_json("/market/screener/conservative-foreign-funds").get("funds")

@daily_cache
def most_actives():
    return get_json("/market/screener/most-actives").get("stocks")

@daily_cache
def most_shorted_stocks():
    return get_json("/market/screener/most-shorted-stocks").get("stocks")

@daily_cache
def undervalued_growth_stocks():
    return get_json("/market/screener/undervalued-growth-stocks").get("stocks")

@daily_cache
def growth_technology_stocks():
    return get_json("/market/screener/growth-technology-stocks").get("stocks")

@daily_cache
def day_gainers():
    return get_json("/market/screener/day-gainers").get("stocks")

@daily_cache
def day_losers():
    return get_json("/market/screener/day-losers").get("stocks")

@daily_cache
def undervalued_large_caps():
    return get_json("/market/screener/undervalued-large-caps").get("stocks")

@daily_cache
def aggresive_small_caps():
    return get_json("/market/screener/aggressive-small-caps").get("stocks")

@daily_cache
def small_cap_gainers():
    return get_json("/market/screener/small-cap-gainers").get("stocks")

@daily_cache
def top_mutual_funds():
    return get_json("/market/screener/top-mutual-funds").get("mutual_funds")

@daily_cache
def portfolio_anchors():
    return get_json("/market/screener/portfolio-anchors").get("stocks")

@daily_cache
def solid_large_growth_funds():
    return get_json("/market/screener/solid-large-growth-funds").get("funds")

@daily_cache
def solid_midcap_growth_funds():
    return get_json("/market/screener/solid-midcap-growth-funds").get("funds")

@daily_cache
def high_yield_bonds():
    return get_json("/market/screener/high-yield-bonds").get("bonds")


from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

@daily_cache
def wallstreetbets_mentions(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/buzz/wall-street-bets-mentions", params).get("wsb_mentions")

@daily_cache    
def news_sentiment(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/buzz/news-sentiment", params).get("sentiment")

@daily_cache    
def news(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/buzz/news", params).get("news")

@daily_cache
def twitter_sentiment(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/buzz/twitter-sentiment", params).get("sentiment")

@daily_cache
def fear_and_greed_index():
    return get_json("/buzz/fear-and-greed-index").get("fear_and_greed_index")



from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *


## company-info ##################################################################################################################################

@daily_cache
def company_profile(ticker_symbol):
	params = {"ticker_symbol": ticker_symbol}
	return get_json("/stock/company-info", params)

def company_name(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["Company Name"]

def sector(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["Sector"]

def industry(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["Industry"]

def business_description(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["Description"]

def website_url(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["Website"]

def full_time_employees(ticker_symbol):
	profile = company_profile(ticker_symbol)["company_profile"]
	if "Full Time Employees" in profile:
		return int(profile["Full Time Employees"])
	else:
		return None

def country(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["Country"]

def state(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["State"]
def city(ticker_symbol):
	return company_profile(ticker_symbol)["company_profile"]["City"]

## quote ########################################################################################################################################

@daily_cache
def quote(ticker_symbol):
	params = {"ticker_symbol": ticker_symbol}
	return get_json("/stock/quote", params)

## historical-prices ####################################################################################################################################

@daily_cache
def historical_prices(ticker_symbol):
	params = {"ticker_symbol": ticker_symbol}
	return get_json("/stock/historical-prices", params)

## key-stats #####################################################################################################################################
def key_stats(ticker_symbol):
	params = {"ticker_symbol": ticker_symbol}
	return get_json("/stock/key-stats", params)




from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

@daily_cache
def raw_quote(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/quote", params).get("quote")

@daily_cache
def raw_historical_prices(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/historical-prices", params)

@daily_cache
def technical_insights(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/technical-insights", params).get("technical_insights")

@daily_cache
def options_contracts(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/options-contracts", params)

@daily_cache
def price(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/price", params).get("price")

@daily_cache
def summary_detail(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/summary-detail", params).get("summary_detail")

@daily_cache
def key_statistics(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/stats", params).get("stats")

@daily_cache
def company_profile(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/company-profile", params).get("company_profile")

@daily_cache
def earnings(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/earnings", params).get("earnings")

@daily_cache
def financial_data(ticker_symbol):
    params = {"ticker_symbol":ticker_symbol}
    return get_json("/yfinance/financial-data", params).get("financial_data")

@daily_cache
def upgrade_downgrade_history(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/upgrade-downgrade-history", params).get("upgrade_downgrade_history")

@daily_cache
def esg_scores(ticker_symbol):
    params = {"ticker_symbol":ticker_symbol}
    return get_json("/yfinance/esg-scores", params).get("esg")

@daily_cache
def calendar_events(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/calendar-events", params).get("calendar_events")

@daily_cache
def annual_income_statement(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/annual-income-statements", params).get("annual_income_statements")

@daily_cache
def quarterly_income_statement(ticker_symbol):
    params = {"ticker_symbol":ticker_symbol}
    return get_json("/yfinance/quarterly-income-statements", params).get("quarterly_income_statements")

@daily_cache
def annual_balance_sheet(ticker_symbol):
    params = {"ticker_symbol":ticker_symbol}
    return get_json("/yfinance/annual-balance-sheets", params).get("annual_balance_sheets")

@daily_cache
def quarterly_balance_sheet(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/yfinance/quarterly-balance-sheets", params).get("quarterly_balance_sheets")


from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

@daily_cache
def risk_free_rate():
    return get_json("/economy/risk-free-rate").get("risk_free_rate")

@daily_cache
def last_year_market_return():
    return get_json("/economy/last-year-market-return").get("last_year_market_return")



from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

## indices ####################################################################################################################################

@daily_cache
def s_and_p_composition():
    return get_json("/market/index/s-and-p-five-hundred").get("stocks")

@daily_cache
def nasdaq_composition():
    return get_json("/market/index/nasdaq-composite").get("stocks")

@daily_cache
def russel_one_thousand_composition():
    return get_json("/market/index/russel-one-thousand").get("stocks")
    
@daily_cache
def amex_oil_composition():
    return get_json("/market/index/amex-oil-index").get("stocks")

@daily_cache
def djia_composition():
    return get_json("/market/index/djia").get("stocks")

@daily_cache
def bbc_global_composition():
    return get_json("/market/index/bbc-global-thirty").get("stocks")

@daily_cache
def ibovespa_composition():
    return get_json("/market/index/ibovespa").get("stocks")
@daily_cache
def ftse100_composition():
    return get_json("/market/index/ftse-one-hundred").get("stocks")

@daily_cache
def ftse250_composition():
    return get_json("/market/index/ftse-two-fifty").get("stocks")

@daily_cache
def nifty_fifty_composition():
    return get_json("/market/index/nifty-fifty").get("stocks")

@daily_cache
def djgt_fifty_composition():
    return get_json("/market/index/dow-jones-global-titans-fifty").get("stocks")

@daily_cache
def dax_thirty_composition():
    return get_json("/market/index/dax-thirty").get("stocks")

@daily_cache
def euro100_composition():
    return get_json("/market/index/euro-next-one-hundred").get("stocks")

@daily_cache
def djta_composition():
    return get_json("/market/index/down-jones-transportation-average").get("stocks")

@daily_cache
def djua_composition():
    return get_json("/market/index/down-jones-utility-average").get("stocks")

@daily_cache
def nasdaq100_composition():
    return get_json("/market/index/nasdaq-one-hundred").get("stocks")

@daily_cache
def phlx_semi_composition():
    return get_json("/market/index/phlx-semiconductor").get("stocks")

@daily_cache
def phlx_gold_composition():
    return get_json("/market/index/phlx-gold-and-silver").get("stocks")

@daily_cache
def nikkei225_composition():
    return get_json("/market/index/nikkei-two-twenty-five").get("stocks")

@daily_cache
def omx_nordic_composition():
    return get_json("/market/index/omx-nordic-forty").get("stocks")

@daily_cache
def nyse_arca_composition():
    return get_json("/market/index/nyse-arca-major-market-index").get("stocks")

@daily_cache
def s_and_p_400():
    return get_json("/market/index/s-and-p-four-hundred").get("stocks")

@daily_cache
def s_and_p_100():
    return get_json("/market/index/s-and-p-one-hundred").get("stocks")

@daily_cache
def s_and_p_global_100():
    return get_json("/market/index/s-and-p-global-one-hundred").get("stocks")

@daily_cache
def russel_2000_composition():
    return get_json("/market/index/russel-two-thousand").get("stocks")

@daily_cache
def niftybank():
    return get_json("/market/index/niftybank").get("stocks")



import setuptools

setuptools.setup(
    name="lattice-stocks-data",
    version="1.0.21",

    description="An API for gathering RapidAPI stock info",
    long_description=" An easy-to-use library for quick access to stock market information. Complete stock market data is available from Yahoo Finance and many other sources in one convenient package. To successfully use this library you will need an API key for the Lattice Stock Market Data API that powers it. Navigate to RapidAPI to sign up for a free API key and then save it to an environment variable called STOCK_DATA_X_RAPID_API_KEY in your environment. The library will automatically load that environment variable and use it to authenticate API calls made under the hood.",
    long_description_content_type="text/markdown",
    url="https://lattice.dev/products/stock-market-data",
    project_urls={
        "Source": "https://github.com/LatticeData/lattice-stocks-data",
        "Documentation" : "https://github.com/LatticeData/lattice-stocks-data/blob/master/README.md#Usage",
        "Bug Reports" : "https://github.com/LatticeData/lattice-stocks-data/issues",
        "Get your key" : "https://rapidapi.com/lattice-data-lattice-data-default/api/stock-market-data/",


    },
    py_modules = ["algorithms","buzz","economy","exchanges","financials","indices","market","screeners","search","similarity",
                    "stock","valuation","yahoo_finance"],
    
    author="ashkon@lattice.dev",
    package_dir={
        "": "./stocksdata",
    },
    
    tests_require=['pytest'],

    python_requires=">=3.7",

    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3 :: Only",
    ],
)



from stocksdata.util.ttlcache import daily_cache
from stocksdata.util.get import *

def wikipedia_url_to_ticker_symbol(wikipedia_url):
    params = {"wikipedia_url": wikipedia_url}
    return get_json("/search/wikpedia-url-to-ticker-symbol", params).get("ticker_symbol")

#def stock_screener(param):
 #   params = param
  #  return get_json("/screener", params).get("stocks")

def isin_to_ticker_symbol(isin):
    params = {"isin": isin}
    return get_json("/search/isin-to-ticker-symbol", params).get("ticker_symbol")

def company_name_to_ticker_symbol(company_name):
    params = {"company_name": company_name}
    return get_json("/search/company-name-to-ticker-symbol", params).get("ticker_symbol")



from stocksdata.util.ttlcache import daily_cache, hourly_cache
from stocksdata.util.get import *


@hourly_cache
def cost_of_equity(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/valuation/cost-of-equity", params).get("cost_of_equity")

@hourly_cache
def enterprise_value(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/valuation/enterprise-value", params).get("enterprise_value")

@hourly_cache
def historical_valuation_measures(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/valuation/historical-valuation-measures", params)

@hourly_cache
def valuation_measures(ticker_symbol):
    params = {"ticker_symbol": ticker_symbol}
    return get_json("/stock/valuation/valuation-measures", params).get("valuation_measures")

def forward_pe(ticker_symbol):
    return valuation_measures(ticker_symbol)["Forward P/E"]

def trailing_pe(ticker_symbol):
    return valuation_measures(ticker_symbol)["Trailing P/E"]

def market_cap(ticker_symbol):
    return valuation_measures(ticker_symbol)["Market Cap (intraday)"]

